@@ -1,8 +1,9 @@
 # aux logging functions
 from logging.handlers import SMTPHandler
 
-from artemis_utils.envvars import (ARTEMIS_WEB_BASE_DIR, ARTEMIS_WEB_HOST,
-                                   HIJACK_LOG_FIELDS)
+from artemis_utils.envvars import ARTEMIS_WEB_BASE_DIR
+from artemis_utils.envvars import ARTEMIS_WEB_HOST
+from artemis_utils.envvars import HIJACK_LOG_FIELDS
 
 
 class TLSSMTPHandler(SMTPHandler):
